OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "內嵌訊息 %s",
    "Important mail" : "重要郵件",
    "Unread mail" : "未讀郵件",
    "Important" : "重要",
    "Work" : "業務",
    "Personal" : "個人",
    "To Do" : "待辦",
    "Later" : "稍後",
    "Mails" : "郵件",
    "Mail" : "郵件",
    "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件賬號！** 私人與公司賬號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 賬號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope]（https://mailvelope.com）瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde]（https://horde.org）函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box]（https://mailinabox.email）！",
    "Your session has expired. The page will be reloaded." : "您的時段已過期。該頁面將重新加載。",
    "Drafts are saved in:" : "草稿儲存於：",
    "Sent messages are saved in:" : "已傳送的郵件儲存於：",
    "Deleted messages are moved in:" : "已刪除的郵件移動至：",
    "Archived messages are moved in:" : "已封存的郵件移動至：",
    "Auto" : "自動",
    "Name" : "姓名",
    "Mail address" : "電郵地址",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "請輸入格式為 name@example.com 的電郵地址",
    "Password" : "密碼",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP 設定",
    "IMAP Host" : "IMAP 主機",
    "IMAP Security" : "IMAP 安全性",
    "None" : "無",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 連接埠",
    "IMAP User" : "IMAP 賬號",
    "IMAP Password" : "IMAP 密碼",
    "SMTP Settings" : "SMTP 設定",
    "SMTP Host" : "SMTP 主機",
    "SMTP Security" : "SMTP 安全性",
    "SMTP Port" : "SMTP 連接埠",
    "SMTP User" : "SMTP 賬號",
    "SMTP Password" : "SMTP 密碼",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "要使 Google 賬戶與此應用程式配合使用，您需要為 Google 啟用雙重認證並生成應用程式密碼。",
    "Connecting" : "連線中",
    "Reconnect Google account" : "重新連接 Google 賬戶",
    "Sign in with Google" : "使用 Google 登入",
    "Save" : "儲存",
    "Connect" : "連線",
    "Looking up configuration" : "查找配置",
    "Checking mail host connectivity" : "檢查郵件主機連接",
    "Configuration discovery failed. Please use the manual settings" : "配置發現失敗。 請使用手動設置",
    "Testing authentication" : "測試認證",
    "Awaiting user consent" : "等待用戶同意",
    "Account created. Please follow the popup instructions to link your Google account" : "賬戶已創建。請按照彈出說明連結您的 Google 賬戶",
    "Loading account" : "加載賬戶",
    "Account updated. Please follow the popup instructions to reconnect your Google account" : "賬戶已更新。請按照彈出說明重新連結您的 Google 賬戶",
    "Account updated" : "賬戶已更新",
    "IMAP server is not reachable" : "IMAP 伺服器無法連線",
    "SMTP server is not reachable" : "SMTP 伺服器無法連線",
    "IMAP username or password is wrong" : "IMAP 用戶名或密碼錯誤",
    "SMTP username or password is wrong" : "SMTP 用戶名或密碼錯誤",
    "IMAP connection failed" : "IMAP 連線失敗",
    "SMTP connection failed" : "SMTP 連線失敗",
    "Google authorization popup closed" : "Google 授權彈窗關閉",
    "There was an error while setting up your account" : "設置您的帳戶時出錯。 ",
    "Account settings" : "賬號設定",
    "Change name" : "更改名稱",
    "Signature" : "簽名",
    "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已附加一個簽名檔",
    "Writing mode" : "書寫模式",
    "Preferred writing mode for new messages and replies." : "新訊息和回覆的首選書寫模式。",
    "Default folders" : "默認資料夾",
    "The folders to use for drafts, sent messages, deleted messages and archived messages." : "用於存儲草稿，已發送郵件，已刪除郵件和已封存郵件的資料夾。",
    "Autoresponder" : "自動回復程式",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "自動回覆收到的訊息。如果有人向您發送多個訊息，此自動回覆最多每 4 天傳送一次。",
    "Please connect to a sieve server first." : "請先連接到篩網伺服器。",
    "Sieve filter rules" : "Sieve 過濾規則",
    "Trusted senders" : "受信任的寄件人",
    "Mail server" : "郵件伺服器",
    "Sieve filter server" : "Sieve 過濾伺服器",
    "Update alias" : "更新别名",
    "Show update alias form" : "顯示更新別名表格",
    "Delete alias" : "删除别名",
    "Email address" : "電郵地址",
    "Add alias" : "新增別名",
    "Create alias" : "創建别名",
    "Cancel" : "取消",
    "Add mail account" : "添加電郵帳戶",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 虛擬化身圖示",
    "Register as application for mail links" : "註冊為處理郵件連結的應用程式",
    "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
    "Looking for a way to encrypt your emails?" : "正在尋找加密電子郵件的方法嗎？",
    "Install Mailvelope browser extension here" : "在此安裝 Mailvelope 瀏覽器擴充套件",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
    "Put my text to the bottom of a reply instead of on top of it." : "將我的文字放在回覆的底部而不是頂部。",
    "Automatically classify importance of new email" : "自動分類新郵件的重要性",
    "Could not update preference" : "無法更新偏愛",
    "From" : "從",
    "Select account" : "選擇賬號",
    "To" : "至",
    "Contact or email address …" : "聯絡人或電郵地址 ...",
    "Toggle recipients list mode" : "切換收件人清單模式",
    "Cc" : "副本",
    "Bcc" : "密件副本",
    "No contacts found." : "找不到聯絡人。",
    "Subject" : "主題",
    "Subject …" : "主題 …",
    "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
    "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
    "Write message …" : "編寫郵件 ...",
    "Saving draft …" : "正在儲存草稿 …",
    "Error saving draft" : "儲存草稿時發生錯誤",
    "Draft saved" : "草稿已儲存",
    "Save draft" : "保存草稿",
    "Discard & close draft" : "丟棄並關閉草稿",
    "Upload attachment" : "已上傳附件",
    "Add attachment from Files" : "從雲端檔案中加入附件",
    "Send later" : "稍後傳送",
    "Enable formatting" : "啟用格式",
    "Disable formatting" : "停用格式",
    "Request a read receipt" : "索取讀取回條",
    "Encrypt message with Mailvelope" : "使用 Mailvelope 加密郵件",
    "Send now" : "立即傳送",
    "Tomorrow morning" : "明天早上",
    "Tomorrow afternoon" : "明天下午",
    "Monday morning" : "星期一早上",
    "Custom date and time" : "自訂日期與時間",
    "Enter a date" : "輸入日期",
    "Uploading attachments …" : "正在上傳附件……",
    "Sending …" : "傳送中 ...",
    "Error sending your message" : "傳送您的郵件時發生錯誤",
    "Go back" : "返回",
    "Retry" : "重試",
    "Warning sending your message" : "傳送您的郵件時發生警告",
    "Send anyway" : "仍然傳送",
    "Message will be sent at" : "訊息將會傳送於",
    "Message sent!" : "信件已寄出",
    "Add share link from {productName} Files" : "從 {productName} 檔案新增分享連結",
    "Send" : "傳送",
    "Encrypt and send" : "加密並傳送",
    "Send unencrypted" : "傳送未加密的",
    "Message {id} could not be found" : "找不到郵件 {id}",
    "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在賬號設定中選取。",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正在嘗試發送給“收件人”和/或“抄送”中的許多收件人。考慮使用密件抄送（Bcc）隱藏收件人地址。",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何現有格式（例如粗體、斜體、下劃線或內嵌圖像）都將被刪除。",
    "Turn off formatting" : "停用格式",
    "Turn off and remove formatting" : "停用並刪除格式",
    "Keep formatting" : "保持格式",
    "Choose a file to add as attachment" : "選擇要作為附件的檔案",
    "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個附件"],
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超過了允許的附件大小 {size}。請透過連結分享檔案。"],
    "No message found yet" : "找不到訊息",
    "Set up an account" : "設定賬號",
    "Plain text" : "純文字",
    "Rich text" : "RTF",
    "No messages in this mailbox" : "此信箱中沒有郵件",
    "No messages" : "沒有訊息",
    "Draft: " : "草稿：",
    "Encrypted message" : "加密訊息",
    "This message is unread" : "此訊息未讀",
    "Unfavorite" : "取消我的最愛",
    "Favorite" : "我的最愛",
    "Unread" : "未讀",
    "Read" : "已讀",
    "Unimportant" : "不重要",
    "Mark not spam" : "標記為非垃圾郵件",
    "Mark as spam" : "標記為垃圾郵件",
    "Unselect" : "取消選擇",
    "Select" : "選擇",
    "Edit tags" : "編輯標籤",
    "Move" : "移動",
    "Move thread" : "移動主題",
    "Archive thread" : "封存主題",
    "Delete thread" : "刪除主題",
    "More actions" : "更多操作",
    "Edit as new message" : "以新郵件的方式編輯",
    "Create event" : "創建活動",
    "Download message" : "下載訊息",
    "Blind copy recipients only" : "僅密件副本收件者",
    "No subject" : "無題",
    "No trash mailbox configured" : "未設定垃圾信箱",
    "Could not delete message" : "無法刪除郵件",
    "Could not archive message" : "無法封存郵件",
    "Forward" : "轉寄",
    "Load more" : "載入更多",
    "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
    "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["將 {number} 標記為重要"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["將 {number} 標記為不重要"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消我的最愛 {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["我的最愛 {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["取消選擇 {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["移動 {number} 主題"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["轉發 {number} 作為附件"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["刪除 {number} 主題"],
    "Report this bug" : "舉報此錯誤 ",
    "All day" : "整日",
    "Create" : "創建",
    "Event created" : "活動已建立",
    "Could not create event" : "無法建立活動",
    "You accepted this invitation" : "您}接受了此邀请。",
    "You tentatively accepted this invitation" : "你暫時接受了此邀請",
    "You declined this invitation" : "您婉拒了拒此邀請",
    "You already reacted to this invitation" : "您已對此邀請作出反應",
    "You have been invited to an event" : "您已受邀參加活動",
    "This event was cancelled" : "此活動已取消",
    "Save to" : "保存到",
    "Comment" : "留言",
    "Accept" : "接受",
    "Decline" : "婉拒",
    "Tentatively accept" : "暫時接受",
    "More options" : "更多選項",
    "This event is in the past." : "此活動已經過去了。",
    "This event was updated" : "此活動已更新",
    "{attendeeName} accepted your invitation" : "{attendeeName} 已接受您的邀請",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} 暫時接受了您的邀請",
    "{attendeeName} declined your invitation" : "{attendeeName} 已婉拒您的邀請",
    "{attendeeName} reacted to your invitation" : "{attendeeName} 已對您的邀請作出反應",
    "Failed to save your participation status" : "無法保存您的參與狀態",
    "Could not open mailbox" : "無法開啟信箱",
    "Loading messages …" : "正在載入訊息 ...",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在索引您的郵件。對於較大的信箱來說，這可能需要較長的時間。",
    "Choose target mailbox" : "選擇目標信箱",
    "No more submailboxes in here" : "這裡沒有更多子信箱",
    "Choose" : "選擇",
    "Important info" : "重要資訊",
    "Other" : "其他",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "郵件將會以您與其互動或標記為重要的郵件為基礎來自動標記重要郵件。ㄧ開始，您可以能必須手動教導系統哪些是重要郵件，然後它就會與時俱進。",
    "The sender of this message has asked to be notified when you read this message." : "此郵件的發件人已要求閱讀確認。",
    "Notify the sender" : "通知寄件人",
    "You sent a read confirmation to the sender of this message." : "你已將讀取回條傳送給此郵件的寄件人。",
    "Could not send mdn" : "無法傳送 mdn",
    "Reply all" : "回覆全部",
    "Reply" : "回覆",
    "Reply to sender only" : "僅回覆寄件人",
    "Move message" : "移動訊息",
    "Forward message as attachment" : "將訊息作為附件轉發",
    "View source" : "檢視原始碼",
    "Download thread data for debugging" : "下載郵件串的資料以供除錯",
    "Message source" : "郵件原始碼",
    "Message body" : "郵件正文",
    "Import into calendar" : "導入到日曆",
    "Download attachment" : "下載附件",
    "Save to Files" : "儲存至雲端檔案",
    "Unnamed" : "未命名",
    "Embedded message" : "內嵌郵件",
    "Choose a folder to store the attachment in" : "選擇一個資料夾來存放附件",
    "View fewer attachments" : "檢視較少附件",
    "Save all to Files" : "全部儲存至檔案",
    "Download Zip" : "下載 Zip",
    "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
    "_View {count} more attachment_::_View {count} more attachments_" : ["檢視另外 {count} 個附件"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
    "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
    "Show images" : "顯示圖像",
    "Show images temporarily" : "暫時顯示圖像",
    "Always show images from {sender}" : "一律顯示來自 {sender} 的圖像",
    "Always show images from {domain}" : "一律顯示來自 {domain} 的圖像",
    "Message frame" : "郵件框",
    "Quoted text" : "引用文字",
    "Moving" : "正在移動",
    "Moving thread" : "移動主題",
    "Moving message" : "移動訊息",
    "Mail settings" : "電郵設定",
    "Provisioned account is disabled" : "預配賬戶已禁用",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "請使用密碼登錄以啟用此賬戶。當前會話正在使用無密碼身份驗證，例如 SSO 或 WebAuthn。",
    "Quota" : "用量",
    "Show only subscribed mailboxes" : "僅顯示已訂閱的信箱",
    "Add mailbox" : "新增信箱",
    "Saving" : "正在儲存",
    "Move up" : "向上移動",
    "Move down" : "向下移動",
    "Remove account" : "移除賬號",
    "Loading …" : "加載中 ...",
    "Not supported by the server" : "不被伺服器支援",
    "{usage} of {limit} used" : "已使用 {limit} 中的 {usage}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 賬號與已快取的電子郵件將會從 Nextcloud 移除，但不會從您的電子郵件提供商移除。",
    "Remove account {email}" : "移除賬號 {email}",
    "Remove {email}" : "移除 {email}",
    "Show all subscribed mailboxes" : "顯示所有已訂閱的信箱",
    "Show all mailboxes" : "顯示所有信箱",
    "Collapse mailboxes" : "收合信箱",
    "Mark all as read" : "全部標記為已讀",
    "Mark all messages of this mailbox as read" : "將此信箱所有的郵件標記為已讀",
    "Add submailbox" : "新增子信箱",
    "Edit name" : "編輯名稱",
    "Clear cache" : "清除緩存",
    "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除近端緩存資料。",
    "Subscribed" : "已訂閱",
    "Sync in background" : "背景同步",
    "Clear mailbox" : "清除信箱",
    "Delete mailbox" : "刪除信箱",
    "All messages in mailbox will be deleted." : "郵箱中的所有訊息都將被刪除。",
    "Clear mailbox {name}" : "清除信箱 {name}",
    "The mailbox and all messages in it will be deleted." : "信箱與其中的所有郵件都會被刪除。",
    "Delete mailbox {name}" : "刪除信箱 {name}",
    "An error occurred, unable to rename the mailbox." : "遇到錯誤，無法重新命名信箱。",
    "_{total} message_::_{total} messages_" : ["{total} 封郵件"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 中的 {unread} 未讀"],
    "Outbox" : "發件箱",
    "New message" : "新郵件",
    "Edit message" : "編輯訊息",
    "Draft" : "草稿",
    "Message discarded" : "訊息已刪除",
    "Could not discard message" : "無法掉棄訊息",
    "No message selected" : "未選擇郵件",
    "Autoresponder off" : "關閉自動回復程式",
    "Autoresponder on" : "開啟自動回復程式",
    "First day" : "第一天",
    "Last day (optional)" : "最後一天（可選）",
    "Message" : "訊息",
    "Oh Snap!" : "哎呀！",
    "Save autoresponder" : "保存自動回復程式",
    "Could not open outbox" : "無法開啟發件箱",
    "Pending or not sent messages will show up here" : "待處理或未傳送的訊息將在此處顯示",
    "Delete" : "刪除",
    "Message could not be sent" : "無法傳送訊息",
    "Message deleted" : "訊息已刪除",
    "Contacts with this address" : "具有此地址的聯絡人",
    "Add to Contact" : "新增聯絡人",
    "New Contact" : "新聯絡人",
    "Copy to clipboard" : "複製到剪貼板",
    "Contact name …" : "聯絡人名稱 ...",
    "Add" : "新增",
    "Search in mailbox" : "在郵箱中搜尋",
    "Search parameters" : "在參數中搜尋",
    "Search term" : "搜尋字詞",
    "Pick a start date" : "挑選開始日期",
    "Pick an end date" : "挑選結束日期",
    "Select sender" : "選取寄件人",
    "Select recipient" : "選擇收件人",
    "Select cc recipient" : "選擇 cc 收件人",
    "Select bcc recipient" : "選擇 bcc 收件人",
    "Tags" : "標籤",
    "Select tags" : "選擇標籤",
    "Marked as" : "已標記為",
    "Has attachments" : "有附件",
    "Clear" : "清除",
    "Search" : "搜尋",
    "Date" : "日期",
    "Disabled" : "停用",
    "Enabled" : "啟用",
    "Sieve Host" : "Sieve 主機",
    "Sieve Security" : "Sieve 安全性",
    "Sieve Port" : "Sieve 連接埠",
    "Sieve Credentials" : "Sieve 身分驗證",
    "IMAP Credentials" : "IMAP 身分驗證",
    "Custom" : "自訂",
    "Sieve User" : "Sieve 賬戶",
    "Sieve Password" : "Sieve 密碼",
    "Save sieve settings" : "保存 Sieve 設置",
    "Save sieve script" : "保存 Sieve 腳本語言（script）",
    "Signature …" : "簽名……",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "您的簽名大於 2 MB。這可能會影響編輯器的性能。",
    "Save signature" : "儲存簽名",
    "Place signature above quoted text" : "將簽名置於引用文字上方",
    "Add default tags" : "添加默認標籤",
    "Rename tag" : "重新命名標籤",
    "Saving new tag name …" : "正在儲存新的標籤名稱……",
    "Set" : "設置",
    "Unset" : "解除設置",
    "Add tag" : "添加標籤",
    "Saving tag …" : "標籤儲存中 ...",
    "Tag name is a hidden system tag" : "標籤名稱是隱藏的系統標籤",
    "Tag already exists" : "標籤已經存在",
    "An error occurred, unable to create the tag." : "發生錯誤，無法建立標籤。",
    "An error occurred, unable to rename the tag." : "發生錯誤，無法重新命名標籤。",
    "Loading thread" : "主題加載中",
    "Not found" : "找不到",
    "Could not load your message thread" : "無法載入您的郵件串",
    "The thread doesn't exist or has been deleted" : "話題不存在或已被刪除",
    "Mark as unfavorite" : "取消標記我的最愛",
    "Mark as favorite" : "標記為我的最愛",
    "Mark as unread" : "標為未讀",
    "Mark as read" : "標為已讀",
    "Archive message" : "封存郵件",
    "Delete message" : "刪除訊息",
    "Remove" : "移除",
    "No senders are trusted at the moment." : "當前沒有發件人是受信任的",
    "Could not remove trusted sender {sender}" : "無法刪除受信任的發件人 {sender}",
    "individual" : "個人",
    "domain" : "網域名稱",
    "(organizer)" : "（主辦人）",
    "Untitled event" : "無標題活動",
    "Import into {calendar}" : "已匯入至 {calendar}",
    "Event imported into {calendar}" : "活動已匯入至 {calendar}",
    "Airplane" : "飛機",
    "Reservation {id}" : "預訂 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "航班 {flightNr} 從 {depAirport} 至 {arrAirport}",
    "Train" : "火車",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 從 {depStation} 至 {arrStation}",
    "Train from {depStation} to {arrStation}" : "從 {depStation} 至 {arrStation} 的火車",
    "Mail app" : "郵件應用程式",
    "The mail app allows users to read mails on their IMAP accounts." : "郵件應用程序使用戶可以閱讀其 IMAP 賬戶上的郵件。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "您可以在此找到全站台的設定。在應用程式本身（左下角）可以找到用戶設定。",
    "Account provisioning" : "帳號設定",
    "A provisioning configuration will provision all accounts with a matching email address." : "供應配置將為所有帳戶供應匹配的電郵地址。",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在配置網域字段中使用通配符（*）將創建一個適用於所有用戶的配置，前提是它與其他配置不匹配。",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "供應機制將特定網域配置優先於通配符網域配置。",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果在為用戶提供另一個配置後發現新的匹配配置，則新配置將優先，用戶將重新提供該配置。",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "每個網域只能有一種配置，並且只能有一種通配符網域配置。",
    "These settings can be used in conjunction with each other." : "這些設置可以相互結合使用。",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想為所有用戶配置一個域，請使用通配符（*）。",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "此設定僅在您組織的 Nextcloud 與郵件伺服器使用相同的使用者後端時才有用。",
    "Provisioning Configurations" : "帳號設定",
    "Add new config" : "添加新配置",
    "Provision all accounts" : "配置所有賬戶",
    "Allow additional mail accounts" : "允許附加的電郵帳戶",
    "Allow additional Mail accounts from User Settings" : "從用戶設置允許附加的電郵帳戶",
    "Anti Spam Service" : "反垃圾郵件服務",
    "You can set up an anti spam service email address here." : "您可以在此設定反垃圾郵件服務的電郵地址。",
    "Any email that is marked as spam will be sent to the anti spam service." : "任何被標記為垃圾郵件的電郵會被傳送到反垃圾郵件服務。",
    "Gmail integration" : "Gmail 整合",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 允許用戶透過 IMAP 存取他們的電子郵件。出於安全原因，只有使用 OAuth 2.0 連接或使用雙重認證和應用程式密碼的 Google 帳戶才能進行此存取。",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必須在 Google Cloud 控制台中為「Web 應用程式」註冊一個新的客戶端 ID。添加 URL {url} 作為授權重定向 URI。",
    "Successfully updated config for \"{domain}\"" : "已成功更新 “{domain}” 的配置",
    "Error saving config" : "存儲配置時發生錯誤",
    "Saved config for \"{domain}\"" : "已成功保存 “{domain}” 的配置",
    "Could not save provisioning setting" : "無法保存配置設置",
    "There was an error when provisioning accounts." : "配置賬戶時出錯。",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "已成功刪除和取消配置 “{domain}” 的賬戶",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "刪除和取消配置“{domain}”的賬戶時出錯",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功配置 {count} 個賬戶。"],
    "Anti Spam" : "反垃圾郵件",
    "Add the email address of your anti spam report service here." : "在此新增您的反垃圾郵件回報服務電郵地址。",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "使用此設置時，當用戶單擊「標記為垃圾郵件」伺服器時，將向 SPAM 報告服務器發送一封報告電郵。",
    "The original message will be attached as a \"message/rfc822\" attachment." : "原始訊息將會以「message/rfc822」作為附件。",
    "\"Mark as Spam\" Email Address" : "「標記為垃圾郵件」電郵地址",
    "\"Mark Not Junk\" Email Address" : "「標記為非垃圾郵件」電郵地址",
    "Reset" : "重設",
    "Successfully set up anti spam email addresses" : "成功設定了反垃圾郵件電郵地址",
    "Error saving anti spam email addresses" : "儲存反垃圾郵件電郵地址時發生錯誤",
    "Successfully deleted anti spam reporting email" : "成功刪除了反垃圾電郵回報電郵地址",
    "Error deleting anti spam reporting email" : "刪除反垃圾郵件回報電郵時發生錯誤",
    "Client ID" : "客戶端 ID",
    "Client secret" : "客戶端密碼",
    "Unlink" : "取消連結",
    "Google integration configured" : "已配置 Google 整合",
    "Could not configure Google integration" : "無法配置 Google 整合",
    "Google integration unlinked" : "取消 Google 整合鏈接",
    "Could not unlink Google integration" : "無法取消 Google 整合連結",
    "Domain Match: {provisioningDomain}" : "網域匹配：{provisioningDomain}",
    "Email: {email}" : "電子郵件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}：{port}（{ssl} 加密）",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}：{port}（{ssl} 加密）",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve：{user} 在 {host}：{port}（{ssl} 加密）",
    "Configuration for \"{provisioningDomain}\"" : "“{provisioningDomain}” 的配置",
    "General" : "一般",
    "Provisioning domain" : "配置網域",
    "Email address template" : "電郵地址模板",
    "IMAP" : "IMAP",
    "User" : "用戶",
    "Host" : "主機",
    "Port" : "連接埠",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "啟用 Sieve 整合",
    "LDAP aliases integration" : "LDAP 别名整合",
    "Enable LDAP aliases integration" : "啟用 LDAP 别名整合",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP 別名集成從已配置的 LDAP 目錄中讀取屬性以供應電子郵件別名。",
    "LDAP attribute for aliases" : "別名的 LDAP 屬性",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "用於配置電郵地址別名的多值屬性。 為每個值創建一個別名。 刪除存在於 Nextcloud 中但不在 LDAP 目錄中的別名。",
    "Save Config" : "保存配置",
    "Unprovision & Delete Config" : "取消配置和刪除配置",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 與 %EMAIL% 將以用戶的 UID 與電郵地址取代",
    "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立賬號：",
    "Account connected" : "賬戶已連結",
    "You can close this window" : "可以關閉此視窗",
    "Keyboard shortcut" : "鍵盤快捷鍵",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "Speed up your Mail experience with these quick shortcuts." : "這些鍵盤快捷鍵可加快您的郵件使用體驗。",
    "Compose new message" : "撰寫新信件",
    "Newer message" : "較新的信件",
    "Older message" : "較舊的信件",
    "Toggle star" : "加上／移除星號",
    "Toggle unread" : "標示未讀／已讀",
    "Refresh" : "重新整理",
    "Connect your mail account" : "連結您的郵件賬號",
    "To add a mail account, please contact your administrator." : "要添加電郵帳戶，請聯繫您的管理員。",
    "Itinerary for {type} is not supported yet" : "目前尚未支援 {type} 的行程",
    "All" : "全部",
    "Archive" : "封存",
    "Drafts" : "草稿",
    "Favorites" : "我的最愛",
    "Priority inbox" : "優先收件匣",
    "All inboxes" : "所有收件匣",
    "Inbox" : "收件匣",
    "Junk" : "垃圾郵件",
    "Sent" : "發送",
    "Trash" : "回收桶",
    "Error while sharing file" : "分享檔案時發生錯誤",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n 則新信件\n來自 {from}"],
    "Nextcloud Mail" : "Nextcloud 郵件",
    "Attachments were not copied. Please add them manually." : "未複製附件。請手動新增它們。",
    "Message sent" : "已傳送訊息",
    "Could not send message" : "無法發送消息",
    "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
    "Could not load your message" : "無法載入您的信件",
    "Could not load the desired message" : "無法載入所選的信件",
    "Could not load the message" : "無法載入信件",
    "Error loading message" : "載入信件錯誤",
    "Forwarding to %s" : "正在轉寄給%s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果未在幾秒內重新導向，請點擊此處。",
    "Redirect" : "重新導向",
    "The link leads to %s" : "該連結導向至 %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想造訪該頁，您可以回到<a href=\"%s\">Mail</a>。",
    "Continue to %s" : "前往 %s"
},
"nplurals=1; plural=0;");
